==> ruby-docs-3.2.2-1-x86_64.pkg.tar.zst: usr/share/doc/ruby/capi/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Topics",url:"topics.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html"},
{text:"Functions",url:"namespacemembers_func.html"},
{text:"Typedefs",url:"namespacemembers_type.html"}]}]},
{text:"Data Structures",url:"annotated.html",children:[
{text:"Data Structures",url:"annotated.html"},
{text:"Data Structure Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions.html#index_b"},
{text:"c",url:"functions.html#index_c"},
{text:"d",url:"functions.html#index_d"},
{text:"e",url:"functions.html#index_e"},
{text:"f",url:"functions.html#index_f"},
{text:"g",url:"functions.html#index_g"},
{text:"h",url:"functions.html#index_h"},
{text:"i",url:"functions.html#index_i"},
{text:"k",url:"functions.html#index_k"},
{text:"l",url:"functions.html#index_l"},
{text:"m",url:"functions.html#index_m"},
{text:"n",url:"functions.html#index_n"},
{text:"o",url:"functions.html#index_o"},
{text:"p",url:"functions.html#index_p"},
{text:"r",url:"functions.html#index_r"},
{text:"s",url:"functions.html#index_s"},
{text:"t",url:"functions.html#index_t"},
{text:"u",url:"functions.html#index_u"},
{text:"v",url:"functions.html#index_v"},
{text:"w",url:"functions.html#index_w"}]},
{text:"Functions",url:"functions_func.html"},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars.html#index_b"},
{text:"c",url:"functions_vars.html#index_c"},
{text:"d",url:"functions_vars.html#index_d"},
{text:"e",url:"functions_vars.html#index_e"},
{text:"f",url:"functions_vars.html#index_f"},
{text:"g",url:"functions_vars.html#index_g"},
{text:"h",url:"functions_vars.html#index_h"},
{text:"i",url:"functions_vars.html#index_i"},
{text:"k",url:"functions_vars.html#index_k"},
{text:"l",url:"functions_vars.html#index_l"},
{text:"m",url:"functions_vars.html#index_m"},
{text:"n",url:"functions_vars.html#index_n"},
{text:"o",url:"functions_vars.html#index_o"},
{text:"p",url:"functions_vars.html#index_p"},
{text:"r",url:"functions_vars.html#index_r"},
{text:"s",url:"functions_vars.html#index_s"},
{text:"t",url:"functions_vars.html#index_t"},
{text:"u",url:"functions_vars.html#index_u"},
{text:"v",url:"functions_vars.html#index_v"},
{text:"w",url:"functions_vars.html#index_w"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"x",url:"globals_x.html#index_x"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"c",url:"globals_func.html#index_c"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"r",url:"globals_vars.html#index_r"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"i",url:"globals_type.html#index_i"},
{text:"r",url:"globals_type.html#index_r"},
{text:"s",url:"globals_type.html#index_s"},
{text:"v",url:"globals_type.html#index_v"}]},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"e",url:"globals_eval.html#index_e"},
{text:"r",url:"globals_eval.html#index_r"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"a",url:"globals_defs_a.html#index_a"},
{text:"b",url:"globals_defs_b.html#index_b"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"h",url:"globals_defs_h.html#index_h"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"o",url:"globals_defs_o.html#index_o"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"q",url:"globals_defs_q.html#index_q"},
{text:"r",url:"globals_defs_r.html#index_r"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"x",url:"globals_defs_x.html#index_x"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}

==> ruby-docs-3.3.5-1-x86_64.pkg.tar.zst: usr/share/doc/ruby/capi/html/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Topics",url:"topics.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html"},
{text:"Functions",url:"namespacemembers_func.html"},
{text:"Typedefs",url:"namespacemembers_type.html"}]}]},
{text:"Data Structures",url:"annotated.html",children:[
{text:"Data Structures",url:"annotated.html"},
{text:"Data Structure Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Data Fields",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__5F"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"}]},
{text:"Functions",url:"functions_func.html"},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__5F"},
{text:"a",url:"functions_vars_a.html#index_a"},
{text:"b",url:"functions_vars_b.html#index_b"},
{text:"c",url:"functions_vars_c.html#index_c"},
{text:"d",url:"functions_vars_d.html#index_d"},
{text:"e",url:"functions_vars_e.html#index_e"},
{text:"f",url:"functions_vars_f.html#index_f"},
{text:"g",url:"functions_vars_g.html#index_g"},
{text:"h",url:"functions_vars_h.html#index_h"},
{text:"i",url:"functions_vars_i.html#index_i"},
{text:"k",url:"functions_vars_k.html#index_k"},
{text:"l",url:"functions_vars_l.html#index_l"},
{text:"m",url:"functions_vars_m.html#index_m"},
{text:"n",url:"functions_vars_n.html#index_n"},
{text:"o",url:"functions_vars_o.html#index_o"},
{text:"p",url:"functions_vars_p.html#index_p"},
{text:"q",url:"functions_vars_q.html#index_q"},
{text:"r",url:"functions_vars_r.html#index_r"},
{text:"s",url:"functions_vars_s.html#index_s"},
{text:"t",url:"functions_vars_t.html#index_t"},
{text:"u",url:"functions_vars_u.html#index_u"},
{text:"v",url:"functions_vars_v.html#index_v"},
{text:"w",url:"functions_vars_w.html#index_w"}]},
{text:"Enumerator",url:"functions_eval.html"}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"Globals",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"a",url:"globals_a.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"c",url:"globals_c.html#index_c"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"f",url:"globals_f.html#index_f"},
{text:"g",url:"globals_g.html#index_g"},
{text:"h",url:"globals_h.html#index_h"},
{text:"i",url:"globals_i.html#index_i"},
{text:"l",url:"globals_l.html#index_l"},
{text:"m",url:"globals_m.html#index_m"},
{text:"n",url:"globals_n.html#index_n"},
{text:"o",url:"globals_o.html#index_o"},
{text:"p",url:"globals_p.html#index_p"},
{text:"q",url:"globals_q.html#index_q"},
{text:"r",url:"globals_r.html#index_r"},
{text:"s",url:"globals_s.html#index_s"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"},
{text:"v",url:"globals_v.html#index_v"},
{text:"x",url:"globals_x.html#index_x"},
{text:"z",url:"globals_z.html#index_z"}]},
{text:"Functions",url:"globals_func.html",children:[
{text:"c",url:"globals_func.html#index_c"},
{text:"p",url:"globals_func_p.html#index_p"},
{text:"r",url:"globals_func_r.html#index_r"},
{text:"s",url:"globals_func_s.html#index_s"}]},
{text:"Variables",url:"globals_vars.html",children:[
{text:"c",url:"globals_vars.html#index_c"},
{text:"l",url:"globals_vars.html#index_l"},
{text:"o",url:"globals_vars.html#index_o"},
{text:"p",url:"globals_vars.html#index_p"},
{text:"r",url:"globals_vars.html#index_r"}]},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"i",url:"globals_type.html#index_i"},
{text:"p",url:"globals_type_p.html#index_p"},
{text:"r",url:"globals_type_r.html#index_r"},
{text:"s",url:"globals_type_s.html#index_s"},
{text:"v",url:"globals_type_v.html#index_v"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"p",url:"globals_enum.html#index_p"},
{text:"r",url:"globals_enum.html#index_r"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"e",url:"globals_eval.html#index_e"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"r",url:"globals_eval_r.html#index_r"}]},
{text:"Macros",url:"globals_defs.html",children:[
{text:"_",url:"globals_defs.html#index__5F"},
{text:"a",url:"globals_defs_a.html#index_a"},
{text:"b",url:"globals_defs_b.html#index_b"},
{text:"c",url:"globals_defs_c.html#index_c"},
{text:"d",url:"globals_defs_d.html#index_d"},
{text:"e",url:"globals_defs_e.html#index_e"},
{text:"f",url:"globals_defs_f.html#index_f"},
{text:"g",url:"globals_defs_g.html#index_g"},
{text:"h",url:"globals_defs_h.html#index_h"},
{text:"i",url:"globals_defs_i.html#index_i"},
{text:"l",url:"globals_defs_l.html#index_l"},
{text:"m",url:"globals_defs_m.html#index_m"},
{text:"n",url:"globals_defs_n.html#index_n"},
{text:"o",url:"globals_defs_o.html#index_o"},
{text:"p",url:"globals_defs_p.html#index_p"},
{text:"q",url:"globals_defs_q.html#index_q"},
{text:"r",url:"globals_defs_r.html#index_r"},
{text:"s",url:"globals_defs_s.html#index_s"},
{text:"t",url:"globals_defs_t.html#index_t"},
{text:"u",url:"globals_defs_u.html#index_u"},
{text:"x",url:"globals_defs_x.html#index_x"},
{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}
